@@ -11,9 +11,8 @@ import urllib.parse
 import urllib.error
 import zlib
 from typing import Callable, List, Optional, Union
-from typing_extensions import Literal
 from hubspot3 import utils
-from hubspot3.utils import force_utf8
+from hubspot3.utils import force_utf8, uglify_hapikey
 from hubspot3.error import (
     HubspotBadConfig,
     HubspotBadRequest,
@@ -27,6 +26,11 @@ from hubspot3.error import (
     HubspotUnauthorized,
 )
 
+try:
+    from typing import Literal  # type: ignore
+except ImportError:
+    from typing_extensions import Literal  # type: ignore
+
 
 class BaseClient:
     """Base abstract object for interacting with the HubSpot APIs"""
@@ -227,8 +231,8 @@ class BaseClient:
     def _execute_request_raw(self, conn, request):
         try:
             result = conn.getresponse()
-        except Exception:
-            raise HubspotTimeout(None, request, traceback.format_exc())
+        except Exception as exception:
+            raise HubspotTimeout(None, request, traceback.format_exc()) from exception
 
         encoding = [i[1] for i in result.getheaders() if i[0] == "content-encoding"]
         possibly_encoded = result.read()
@@ -319,8 +323,7 @@ class BaseClient:
         # Never retry a POST, PUT, or DELETE unless explicitly told to
         if method != "GET" and not opts.get("retry_on_post"):
             num_retries = 0
-        if num_retries > 6:
-            num_retries = 6
+        num_retries = min(num_retries, 6)
 
         emergency_brake = 10
         try_count = 0
@@ -338,7 +341,7 @@ class BaseClient:
                 result = self._execute_request_raw(connection, request_info)
                 break
             except HubspotUnauthorized:
-                self.log.warning("401 Unauthorized response to API request.")
+                self.log.debug("401 Unauthorized response to API request.")
                 if (
                     self.access_token
                     and self.refresh_token
@@ -354,7 +357,7 @@ class BaseClient:
 
                     from hubspot3.oauth2 import OAuth2Client
 
-                    self.log.info("Refreshing access token")
+                    self.log.debug("Refreshing access token")
                     try:
                         client = OAuth2Client(**self.options)
                         refresh_result = client.refresh_tokens(
@@ -364,9 +367,7 @@ class BaseClient:
                         )
                         self.access_token = refresh_result["access_token"]
                         self.refresh_token = refresh_result["refresh_token"]
-                        self.log.info(
-                            "Retrying with new token {}".format(self.access_token)
-                        )
+                        self.log.debug("Retrying with new token")
                     except Exception as exception:
                         self.log.error(
                             "Unable to refresh access_token: {}".format(exception)
@@ -391,14 +392,18 @@ class BaseClient:
                 raise
             except HubspotError as exception:
                 if try_count > num_retries:
-                    logging.warning("Too many retries for {}".format(url))
+                    logging.warning(
+                        "Too many retries for {}".format(uglify_hapikey(url))
+                    )
                     raise
                 # Don't retry errors from 300 to 499
                 if exception.result and 300 <= exception.result.status < 500:
                     raise
                 self._prepare_request_retry(method, url, headers, data)
                 self.log.warning(
-                    "HubspotError {} calling {}, retrying".format(exception, url)
+                    "HubspotError {} calling {}, retrying".format(
+                        exception, uglify_hapikey(url)
+                    )
                 )
             # exponential back off
             # wait 0 seconds, 1 second, 3 seconds, 7 seconds, 15 seconds, etc
