@@ -2,6 +2,7 @@
 hubspot cms_files api
 """
 from hubspot3.base import BaseClient
+from typing import Dict
 
 
 CMS_FILES_API_VERSION = "2"
@@ -15,5 +16,5 @@ class CMSFilesClient(BaseClient):
     def _get_path(self, subpath: str) -> str:
         return "filemanager/api/v{}/files/{}".format(CMS_FILES_API_VERSION, subpath)
 
-    def get_file_meta_data(self, file_id: int, **options):
+    def get_file_meta_data(self, file_id: int, **options) -> Dict:
         return self._call("{}".format(file_id), **options)
